# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.1] - 2021-02-18
### Fixed  
- Restored ability to easily execute queries with multiple statements by switching Redshift driver from `redshift_connector` to `pg8000`.
- Fixed type hints for some S3 functions.

## [0.0.0] - 2021-02-01
- Initial release
